==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-volume/volume_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="62"/>
        <source>Increase sound volume</source>
        <translation>Ses seviyesini yükselt</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="68"/>
        <source>Decrease sound volume</source>
        <translation>Ses seviyesini azalt</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="74"/>
        <source>Mute/unmute sound volume</source>
        <translation>Sessiz/Sesi Aç</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="135"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Ses Kontrol: Aşağıdaki kısayollar kaydedilemez: %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="223"/>
        <location filename="../../../lxqtvolume.cpp" line="233"/>
        <source>Volume: %1</source>
        <translation>Ses: %1</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Ses Kontrol Ayarları</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Kullanılan aygıt</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="28"/>
        <source>Alsa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Davranış</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Orta tıklama sessize alır</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Fare tıkladığında göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>100% (0dB) üzerine izin ver</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="92"/>
        <source>Volume adjust step</source>
        <translation>Ses ayar adımı</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="111"/>
        <source>External Mixer</source>
        <translation>Harici Karıştırıcı</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../../../volumepopup.cpp" line="53"/>
        <source>Launch mixer</source>
        <translation>Karıştırıcıyı aç</translation>
    </message>
    <message>
        <location filename="../../../volumepopup.cpp" line="54"/>
        <source>Mi&amp;xer</source>
        <translation>&amp;Karıştırıcı</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-volume/volume_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="63"/>
        <source>Increase sound volume</source>
        <translation>Ses seviyesini yükselt</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="69"/>
        <source>Decrease sound volume</source>
        <translation>Ses seviyesini azalt</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="75"/>
        <source>Mute/unmute sound volume</source>
        <translation>Sessiz/Sesi Aç</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="136"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Ses Kontrol: Aşağıdaki kısayollar kaydedilemez: %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="287"/>
        <source>Volume: muted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="289"/>
        <source>Volume: %1</source>
        <translation>Ses: %1</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Ses Kontrol Ayarları</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Kullanılan aygıt</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="28"/>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Davranış</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Orta tıklama sessize alır</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Fare tıkladığında göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>100% (0dB) üzerine izin ver</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>Ses ayar adımı</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>Harici Karıştırıcı</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../../../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>Karıştırıcıyı aç</translation>
    </message>
    <message>
        <location filename="../../../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>&amp;Karıştırıcı</translation>
    </message>
</context>
</TS>
